/*
*  Rubrica
*  file: addressbook.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


#include <gnome.h>
#include <gconf/gconf-client.h>

#include "addressbook.h"
#include "autosave.h"
#include "callbacks.h"
#include "dialoghi.h"
#include "file.h"
#include "file_util.h"
#include "interface.h"
#include "main.h"
#include "prefer.h"
#include "rubrica.h"
#include "rubrica_log.h"


RubricaAddressBook *addressbook = NULL;
gboolean have_addressbook = FALSE;
gboolean closing_page = FALSE;


/*    rubrica_addressbook_new, pu essere richiamata una
      sola volta. Inizializza la variabile globale
      addressbook
*/
void rubrica_addressbook_new(void) 
{
  if (!have_addressbook)
    addressbook = (RubricaAddressBook *) g_malloc(sizeof(RubricaAddressBook));
  else
    return;
    
  if (addressbook == NULL)
    {
      gchar *str = g_strdup(_("Out of memory! can't allocate memory for addressbook"));

      rubrica_log_write_log(str);
      g_error(str);      
    }

  have_addressbook = TRUE;
}



void rubrica_addressbook_init(void)
{  
  addressbook->notebook = gtk_notebook_new();  /* il notebook viene mostrato da interface.c */

  addressbook->books = NULL;                   /* lista delle rubriche */
  addressbook->pages = 0;                      /* Pagine totali.       */
  addressbook->current_page = 0;               /* pagina attuale       */    

  addressbook->show_card       = rubrica_preferences_show_card();
  addressbook->show_first_name = rubrica_preferences_show_first_name();
  addressbook->show_last_name  = rubrica_preferences_show_last_name();
  addressbook->show_profession = rubrica_preferences_show_profession();
  addressbook->show_city       = rubrica_preferences_show_city(); 
  addressbook->show_country    = rubrica_preferences_show_country(); 
  addressbook->show_web        = rubrica_preferences_show_web();
  addressbook->show_email      = rubrica_preferences_show_email();
  addressbook->show_telephone  = rubrica_preferences_show_telephone();
  addressbook->show_comapany   = rubrica_preferences_show_company();
  addressbook->show_assigment  = rubrica_preferences_show_assigment();
}



RubricaAddressBook *rubrica_get_addressbook(void)
{
  return addressbook;
}


/*  makes a new child for notebook
*/
GtkWidget *rubrica_addressbook_new_notebook_child(GtkWidget **clst)
{
  GtkWidget *scroll; /* scrolled window, this is the child of notebook page  */
  GtkWidget *cards;  /* cards clist, the core of page */ 
  GtkWidget *label;  

  /*     SCROLLED WINDOW
  */
  scroll = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scroll, "scrollwin");
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll), 
				  GTK_POLICY_AUTOMATIC, 
				  GTK_POLICY_AUTOMATIC);
  gtk_widget_show (scroll);

  /* -------------------------------------------------------------------- */
  /* -------------------------------------------------------------------- */

  /*      CARDS CLIST 
   */
  cards = gtk_clist_new (12);
  *clst = cards;
  gtk_widget_set_name (cards, "cards");
  gtk_widget_ref (cards);
  gtk_object_set_data_full (GTK_OBJECT (scroll), "cards", cards,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_clist_set_column_width (GTK_CLIST (cards), 0, 20);
  gtk_clist_set_column_width (GTK_CLIST (cards), 1, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 2, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 4, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 5, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 6, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 7, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 8, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 9, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 10, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 11, 110);
  gtk_clist_set_column_width (GTK_CLIST (cards), 12, 110);

  gtk_container_add (GTK_CONTAINER (scroll), cards);

  /*    active clist button
   */
  gtk_clist_column_title_active(GTK_CLIST (cards), 1);
  gtk_clist_column_title_active(GTK_CLIST (cards), 2);
  gtk_clist_column_title_active(GTK_CLIST (cards), 3);
  gtk_clist_column_title_active(GTK_CLIST (cards), 4);
  gtk_clist_column_title_active(GTK_CLIST (cards), 5);
  gtk_clist_column_title_active(GTK_CLIST (cards), 6);
  gtk_clist_column_title_active(GTK_CLIST (cards), 7);
  gtk_clist_column_title_active(GTK_CLIST (cards), 8);
  gtk_clist_column_title_active(GTK_CLIST (cards), 9);
  gtk_clist_column_title_active(GTK_CLIST (cards), 10);
  gtk_clist_column_title_active(GTK_CLIST (cards), 11);

  gtk_clist_column_titles_show (GTK_CLIST (cards));
  gtk_widget_set_events (cards, GDK_BUTTON_PRESS | GDK_2BUTTON_PRESS |
			 GDK_3BUTTON_PRESS | GDK_BUTTON_RELEASE);
  gtk_widget_show (cards);

  /*    Clist button, labels pixmap column, no label
  */
  label = gtk_label_new ("");
  gtk_clist_set_column_widget (GTK_CLIST (cards), 0, label);
  gtk_widget_show (label);

  /*    card label
   */
  label = gtk_label_new (_("Card"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 1, label);
  gtk_widget_show (label);

  /*    First Name (nome proprio) label
   */
  label = gtk_label_new (_("First Name"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 2, label);
  gtk_widget_show (label);

  /*    Last Name (cognome) label
  */
  label = gtk_label_new (_("Last Name"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 3, label);
  gtk_widget_show (label);

  /*    Profession label
  */
  label = gtk_label_new (_("Profession"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 4, label);
  gtk_widget_show (label);

  /*    City label
  */
  label = gtk_label_new (_("City"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 5, label);
  gtk_widget_show (label);

  /*    Country label
  */
  label = gtk_label_new (_("Country"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 6, label);
  gtk_widget_show (label);

  /*    Web label
  */
  label = gtk_label_new (_("Web"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 7, label);
  gtk_widget_show (label);

  /*    Email label
  */
  label = gtk_label_new (_("Email"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 8, label);
  gtk_widget_show (label);

  /*    Telephone label
  */
  label = gtk_label_new (_("Telephone"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 9, label);
  gtk_widget_show (label);

  /*    Company label
  */
  label = gtk_label_new (_("Company"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 10, label);
  gtk_widget_show (label);

  /*    Assigment label
  */
  label = gtk_label_new (_("Assigment"));
  gtk_clist_set_column_widget (GTK_CLIST (cards), 11, label);
  gtk_widget_show (label);

  /* -------------------------------------------------------------------- */
  /* -------------------------------------------------------------------- */

  if (!rubrica_preferences_show_card())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 1, FALSE);
  if (!rubrica_preferences_show_first_name())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 2, FALSE);
  if (!rubrica_preferences_show_last_name())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 3, FALSE);
  if (!rubrica_preferences_show_profession())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 4, FALSE);
  if (!rubrica_preferences_show_city())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 5, FALSE);
  if (!rubrica_preferences_show_country())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 6, FALSE);
  if (!rubrica_preferences_show_web())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 7, FALSE);
  if (!rubrica_preferences_show_email())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 8, FALSE);
  if (!rubrica_preferences_show_telephone())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 9, FALSE);
  if (!rubrica_preferences_show_company())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 10,FALSE);
  if (!rubrica_preferences_show_assigment())
    gtk_clist_set_column_visibility(GTK_CLIST (cards), 11, FALSE);                    

  /*    CALLBACK
  */
  gtk_signal_connect(GTK_OBJECT (cards), "select_row",
		     GTK_SIGNAL_FUNC (on_schede_clist_select_row),
		     NULL);
  gtk_signal_connect(GTK_OBJECT(cards), "button_press_event",
		     GTK_SIGNAL_FUNC(on_schede_clist_button_click),
		     NULL);
  gtk_signal_connect(GTK_OBJECT(cards), "click_column",
		     GTK_SIGNAL_FUNC(on_clicked_column_cb),
		     NULL);

  return (GtkWidget*) scroll;
}


/*  clean the addressbook view
 */ 
void rubrica_addressbook_init_view(void)
{
  GtkCList *dati;
  
  /* pulisco la clist dati  */
  dati = rubrica_view_get_dati(); 
  gtk_clist_clear(GTK_CLIST(dati));    
}

/*  add into addressbook's notebook a new page with the 
    content of file "filename"

    return the number of new page
*/
gint rubrica_addressbook_add_page(gchar *filename)
{
  Rubrica   *rubrica;       /* the new addressbook item */
  GtkWidget *child;         /* notebook child, this will contain cards clist */
  GtkWidget *label;         /* notebook tab label */
  GtkWidget *clist;         /* the cards clist */
  gint       page;          /* the # of the new notebook's page */
  gchar     *path; 
  gchar     *fname = NULL;

  if (filename)
    {
      path  = g_dirname(filename);
      fname = g_basename(filename);
    }
  else
    path = rubrica_preferences_get_home();

  /*    build new addressbook, init and insert it in addressbooks list. 
	It will be related to new notebook page  
  */
  rubrica = rubrica_rubrica_new();

  /*    make notebook page's child 
   */
  child = rubrica_addressbook_new_notebook_child(&clist);

  /*    tab label 
	NOTA:
	l'etichetta da inserire nel notebook, NON DEVE ESSERE MOSTRATA
	DON'T SHOW the label that will be inserted in notebook  
  */  
  if (!fname)
    fname = _("no name");
  label = gtk_label_new (fname);  

  /*      get the number of this new page 
   */
  page = rubrica_addressbook_get_pages();

  /*      store infos about this addressbook/page 
   */
  rubrica->rub      = NULL;
  rubrica->new      = TRUE;
  rubrica->modified = FALSE;
  rubrica->empty    = TRUE; 
  rubrica->name     = (fname ? g_strdup(fname) : NULL);
  rubrica->path     = (path  ? g_strdup(path)  : NULL);
  rubrica->child    = child;
  rubrica->clist    = clist;
  rubrica->label    = label;
  rubrica->items    = 0;
  rubrica->riga     = -1;
  rubrica->colonna  = 0;
  rubrica->pagina   = page;

  /*      append new addressbook in addressbook's book 
   */
  rubrica_addressbook_append_rubrica(rubrica); 
  gtk_object_set_data(GTK_OBJECT(child), "rubrica", rubrica);

  gtk_notebook_append_page(GTK_NOTEBOOK(addressbook->notebook), 
			   rubrica->child, rubrica->label);  

  rubrica_addressbook_make_this_rubrica_current(rubrica);

  /*      make this page the current one 
   */
  rubrica_addressbook_set_current_page(page); 

  /*      increase pages counter. Il valore di
	  pages, indica la posizione in cui 
	  sar inserita la prossima nuova pagina 
  */
  rubrica_addressbook_inc_pages();            
  
  /*      switch to page number "page" 
  */
  gtk_notebook_set_page(GTK_NOTEBOOK(addressbook->notebook), page);  

  /*      return the number of new page 
   */
  return (gint) page;  
}




/* 
 *  ritorna la rubrica associata alla pagina "page" del notebook
 *  return the addressbook in position number page 
 */
Rubrica *rubrica_addressbook_get_rubrica(gint page)
{

  GtkWidget *child;
  Rubrica *rub = NULL;
  
  child = gtk_notebook_get_nth_page (GTK_NOTEBOOK(addressbook->notebook), page);

  rub = gtk_object_get_data(GTK_OBJECT(child), "rubrica");

  return (Rubrica *) rub;
}

GtkWidget *rubrica_addressbook_get_clist(gint page)
{
  GtkWidget *child;
  GtkWidget *list;

  child = gtk_notebook_get_nth_page (GTK_NOTEBOOK(addressbook->notebook), page);

  list = gtk_object_get_data(GTK_OBJECT(child), "cards");

  return (GtkWidget *) list;
}

/*
 *
 *  copia il contenuto delle variabili rubrica, clist, ecc, relative al 
 *  addressbook selezionato nelle corrispondenti variabili globali
 *
 *  copy the content of addressbook number page to global variables.
 *
*/
void rubrica_addressbook_make_this_page_current(gint page)
{
  Rubrica *r;

  r = rubrica_addressbook_get_rubrica(page);
  rubrica_addressbook_make_this_rubrica_current(r);
}

void rubrica_addressbook_make_this_rubrica_current(Rubrica *rub)
{
  GtkWidget *window;
  gchar *book;  
  
  window = rubrica_get_app();  
  
  /* addressbook->book is a list of lists and contains all addressbooks 
     opened. Each notebook page is one addressbook. Data contained in 
     list item contains ptr to real addressbook, plus some infos about 
     the addressbook.
  */  
  if (!rub)
    return;
  
  /* save the current values of rubrica */
  if (!rubrica_addressbook_is_closing_page())
    rubrica_save_rubrica();

  /* set rub contents as current rubrica values */
  rubrica_copy_rubrica(rub);
  
  /* imposto la chiave RUBRICA_KEY_LAST_BOOK di gconf con
     path e file name del file attualmente visibile

     set gconf key-value of RUBRICA_KEY_LAST_BOOK to 
     path and file name of current used file
  */  
  rubrica_view_update_path(rub->path);

  if (rub->name)
    book = g_strdup_printf("%s/%s", rub->path, rub->name);
  else
    book = g_strdup_printf("%s/%s", rub->path, _("no name"));    

  rubrica_preferences_set_last_book(book);
  g_free(book);

  if (rubrica_is_modified())
    {
      gchar *tmp;

      tmp = g_strdup_printf("Rubrica -- %s changed --", rub->name);

      gtk_window_set_title(GTK_WINDOW(window), _(tmp));
      
      g_free(tmp);
    }
  else
    gtk_window_set_title(GTK_WINDOW(window), "Rubrica");
  
  rubrica_view_set_indirizzi(rub->items);    
}


/* 
 *  insert a new rubrica in addressbook list
 */

void rubrica_addressbook_append_rubrica(Rubrica *r) 
{ 
  addressbook->books  = g_list_append(addressbook->books, r); 
} 



/* 
 * return the number of addressbooks 
 * ritorna il numero di rubriche contenute nell'addressbook
 */
inline gint 
rubrica_addressbook_get_pages(void)
{
  return addressbook->pages;
}

/* 
 * set addressbook number to n 
 * imposta il numero di rubriche ad n
 */
inline void 
rubrica_addressbook_set_page(gint n)
{
  addressbook->pages = n;
}

/* 
 * set current addressbook to the nth 
 * imposta il numero di rubricha corrente all'nesima
 */
inline gint
rubrica_addressbook_get_current_page(void)
{
  return gtk_notebook_get_current_page(GTK_NOTEBOOK(addressbook->notebook));
}

inline void 
rubrica_addressbook_set_current_page(gint n)
{
  addressbook->current_page = n;
}


/* 
 * add an addressbook 
 * incrementa le pagine del notebook (chiamata quando 
 * si carica un nuovo file di rubrica)
 */
inline void 
rubrica_addressbook_inc_pages(void)
{
  addressbook->pages++;
}


/* 
 * delete an addressbook 
 * decrementa le pagine del notebook (un file 
 * stato chiuso)
 */
inline void 
rubrica_addressbook_dec_pages(void)
{
  addressbook->pages--;
}

/* 
 * get the notebook ptr
 */
GtkWidget *rubrica_addressbook_get_notebook(void)  
{
  return (GtkWidget*) addressbook->notebook;
}


gboolean rubrica_addressbook_is_closing_page(void)
{
  return (gboolean) closing_page;
}

void rubrica_addressbook_set_closing_page(gboolean bool)
{
  closing_page = bool;
}


/* 
 *  metodi per operare sugli elementi contenuti 
 *  nella struttuta data (GList *book)
 *  di addressbook
 */


/*
 *  save the ptr to rubrica and rubrica's state (modified, empty, ...) of 
 *  addressbook contained in page number "pos"
 *
 */
void rubrica_addressbook_set_info(GList *rub, 
				  gboolean new, gboolean mod, gboolean emp, 
				  gchar *path, gchar *name,
				  GtkWidget *child, GtkWidget *clist, GtkWidget *label,
				  gint riga, gint colonna, 
				  gboolean rub_flag, gboolean flags_flag, 
				  gboolean name_flag, gboolean widget_flag, 
				  gboolean xy_flag, gint pos)
{
  Rubrica *rubrica;

  if (pos < 0)
    return;
  
  rubrica = rubrica_addressbook_get_rubrica(pos);
  if (!rubrica)
    return;
      

  if (rub_flag)
    {
      rubrica->rub   = rub;      
      rubrica->items = g_list_length(rub);
    }


  if (flags_flag)
    {
      rubrica->new      = new;
      rubrica->modified = mod;
      rubrica->empty    = emp;
      rubrica->items    = g_list_length(rub);
   }


  if (name_flag)
    {
      if (rubrica->path)
	g_free(rubrica->path);
      rubrica->path = g_strdup(path);

      if (rubrica->name)
	g_free(rubrica->name);
      rubrica->name = g_strdup(name);
  
      /* show new filename in notebook tab */
      gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(addressbook->notebook), 
				      rubrica->child, rubrica->name);      
    }


  if (widget_flag)
    {      
      rubrica->child = child;
      rubrica->clist = clist;
      rubrica->label = label;
    }


  if (xy_flag)
    {
      if (riga != -1)	
	rubrica->riga    = riga;
      if (colonna != -1)
	rubrica->colonna = colonna;
    }
  
  rubrica->pagina = pos;           
}



/* 
 * return path and filename of addressbook number page
 * if the selected page don't contain addressbook then return NULL
 *
 */
void rubrica_addressbook_get_path_and_name(gchar **path, gchar **name, gint page)
{ 
  Rubrica *rubrica;
  
  rubrica = rubrica_addressbook_get_rubrica(page);
  
  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");
      
      *path = NULL;
      *name = NULL;
      return;
    }

  if (path)
    *path = g_strdup(rubrica->path);
  if (name)
    *name = g_strdup(rubrica->name);
}


gint rubrica_addressbook_get_items(gint page)
{
  Rubrica *rubrica;
  
  rubrica = rubrica_addressbook_get_rubrica(page);
  
  if (!rubrica)
    return -1;
  
  return rubrica->items;
}


gint rubrica_addressbook_get_row(gint page)
{
  Rubrica *rubrica;
  
  rubrica = rubrica_addressbook_get_rubrica(page);
  
  if (!rubrica)
    return -1;
  
  return rubrica->riga;
}


gint rubrica_addressbook_get_column(gint page)
{
  Rubrica *rubrica;
  
  rubrica = rubrica_addressbook_get_rubrica(page);
  
  if (!rubrica)
    return -1;
  
  return rubrica->colonna;
}


gint rubrica_addressbook_get_page(gint page)
{
  Rubrica *rubrica;
  
  rubrica = rubrica_addressbook_get_rubrica(page);
  
  if (!rubrica)
    return -1;
  
  return rubrica->pagina;
}



/*
 *  save widget info of addressbook contained in page number "pos" 
 */
void rubrica_addressbook_set_widget_info(GtkWidget *child, GtkWidget * clist, 
					 GtkWidget *label, gint page) 
{
  rubrica_addressbook_set_info(NULL, 
			       FALSE, FALSE, FALSE, 
			       NULL, NULL, 
			       child, clist,label, 
			       -1, -1,
			       FALSE, FALSE, FALSE, TRUE, FALSE,
			       page);
}


void rubrica_addressbook_set_label_text(gchar *str, gint page)
{
  Rubrica *rubrica;

  rubrica = rubrica_addressbook_get_rubrica(page);

  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");

      return;
    }
  
  gtk_label_set_text(GTK_LABEL(rubrica->label), str); 
}


void rubrica_addressbook_set_items(gint items, gint page)
{
  Rubrica *rubrica;

  rubrica = rubrica_addressbook_get_rubrica(page);

  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");

      return;      
    }
  
  rubrica->items = items;
}


/*    save path and name in addressbook number page
 */
void rubrica_addressbook_set_row_and_column(gint riga, gint colonna, gint page) 
{
  rubrica_addressbook_set_info(NULL, 
			       FALSE, FALSE, FALSE,
			       NULL, NULL, 
			       NULL, NULL, NULL, 
			       riga, colonna, 
			       FALSE, FALSE, FALSE, FALSE, TRUE,
			       page);
}


void rubrica_addressbook_set_row(gint riga, gint page)
{
  Rubrica *rubrica;

  rubrica = rubrica_addressbook_get_rubrica(page);

  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");

      return;      
    }
  
  rubrica->riga = riga;
}


void rubrica_addressbook_set_column(gint column, gint page)
{
  Rubrica *rubrica;

  rubrica = rubrica_addressbook_get_rubrica(page);

  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");

      return;      
    }
  
  rubrica->colonna = column;
}


/*    save path and name in addressbook number page
*/
void rubrica_addressbook_set_path_and_name(gchar *path, gchar *name, gint page)
{
  rubrica_addressbook_set_info(NULL, 
			       FALSE, FALSE, FALSE, 
			       path, name, 
			       NULL, NULL, NULL, 
			       -1, -1, 
			       FALSE, FALSE, TRUE, FALSE, FALSE,
			       page);
}


void rubrica_addressbook_set_path(gchar *path, gint page)
{
  Rubrica *rubrica;

  rubrica = rubrica_addressbook_get_rubrica(page);

  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");

      return;
    }
  
  if (rubrica->path)
    g_free(rubrica->path);
  rubrica->path = g_strdup(path);   
}


void rubrica_addressbook_set_name(gchar *name, gint page)
{
  Rubrica *rubrica;
  
  rubrica = rubrica_addressbook_get_rubrica(page);
  
  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");

      return;
    }
  
  if (rubrica->name)
    g_free(rubrica->name);
  rubrica->name = g_strdup(name);   
}


void rubrica_addressbook_set_tmpfile_name(gint rand_num, gint page)
{
  Rubrica *rubrica;
  gchar *home;
  
  rubrica = rubrica_addressbook_get_rubrica(page);
  home = g_get_home_dir();

  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");

      return;
    }
  
  if (rubrica->tmpfile)
    g_free(rubrica->tmpfile);

  rubrica->tmpfile = g_strdup_printf("%s/.rubrica/rubrica%d.tmp", home, rand_num);     
}

/*
 * store the new ptr to rubrica if the old one was changed
 */
void rubrica_addressbook_set_rubrica(GList *rub, gint page) 
{
  rubrica_addressbook_set_info(rub, 
			       FALSE, FALSE, FALSE, 
			       NULL, NULL, 
			       NULL, NULL, NULL, 
			       -1, -1, 
			       TRUE, FALSE, FALSE, FALSE, FALSE,
			       page);
}


/*
 * set the flags of rubrica stored in "page" position
 */
void rubrica_addressbook_set_flags(gboolean modified, gboolean new, gboolean empty, gint page) 
{
  rubrica_addressbook_set_info(NULL, 
			       new, modified, empty, 
			       NULL, NULL, 
			       NULL, NULL, NULL, 
			       -1, -1,
			       FALSE, TRUE, FALSE, FALSE, FALSE,
			       page);
}



/*
 * set one flag of the three of rubrica
 */
void rubrica_addressbook_set_flag(gboolean val, gboolean is_new, gboolean is_modified, 
				  gboolean is_empty, gint page) 
{
  Rubrica *rubrica;

  rubrica = rubrica_addressbook_get_rubrica(page);

  if (!rubrica)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");

      return;
    }
  
  if (is_new)
    {
      rubrica->new = val;      
    }
  if (is_empty)
    {
      rubrica->empty = val;
    }
  if (is_modified)
    {
      rubrica->modified = val;
    }
}


/*
 *  set flags and rubrica ptr
 */
void rubrica_addressbook_set_rubrica_and_flags(GList *rub, gboolean new, 
					       gboolean modif, gboolean empty,
					       gint page)
{
  rubrica_addressbook_set_info(rub, 
			       new, modif, empty, 
			       NULL, NULL, 
			       NULL, NULL, NULL, 
			       -1, -1,
			       TRUE, TRUE, FALSE, FALSE, FALSE, 
			       page);
}


gboolean rubrica_addressbook_heve_modified()
{
  GList *alias;
  Rubrica *rub;
  gboolean bool = FALSE;

  alias = addressbook->books;

  while (alias)
    {
      rub = (Rubrica *) alias->data;

      bool |=  rub->modified;

      alias = g_list_next(alias);     
    }

  return bool;  
}


void rubrica_addressbook_close(void)
{    
  Rubrica *rub;
  gint scelta, current_page;
  gchar *mes;
  
  current_page = gtk_notebook_get_current_page(GTK_NOTEBOOK((addressbook->notebook)));

  rub = rubrica_addressbook_get_rubrica(current_page);
  
  if (!rub)
    {
      g_warning("errore, nessun addressbook alla pagina richiesta");
      
      return;
    }

  if (rub->modified)
    {
      mes = g_strdup(_("Warning. Address book has changed.\nChanges not saved will be loose.\nDo you want continue?")); 
      
      scelta = confirm_action(mes);
      g_free(mes);
      
      switch(scelta)
	{
	case 0:
	  /* delete addressbook, go down an delete */
	  break;
	  
	case 1:
	default:
	  return;
	  break;
	}  
    }

  rubrica_addressbook_set_closing_page(TRUE);

  /*      clean view window 
   */
  rubrica_addressbook_init_view();  

  /*      remove this node from addressbook's list 
  */
//  addressbook->book = g_list_remove(addressbook->book, rub); 


  rubrica_svuota_memoria(rub->rub);         /* delete rubrica's contents */

  if (rub->name)                            /* delete path and filename  */
    g_free(rub->name);                             
  if (rub->path)
    g_free(rub->path);           

  if (current_page != 0)
    {          
      gtk_object_remove_data(GTK_OBJECT(rub->child), "rubrica");

      gtk_notebook_remove_page(GTK_NOTEBOOK(addressbook->notebook), current_page);     
      
      gtk_object_unref(GTK_OBJECT(rub->child));
            
      rubrica_addressbook_dec_pages();          /* update pages counter */    
    }
  else
    {
      gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(addressbook->notebook), 
				      rub->child, 
				      _("no name"));
      
      gtk_clist_clear(GTK_CLIST(rub->clist));     
      
      rub->rub      = NULL;
      rub->new      = TRUE;
      rub->modified = FALSE;
      rub->empty    = TRUE;           
      rub->name     = g_strdup(_("no name"));
      rub->path     = g_strdup(rubrica_preferences_get_home());
      rub->items    = 0;
      rub->riga     = -1;
      rub->colonna  = 0;
      rub->pagina   = 0;              
      
/*
      rubrica_addressbook_set_rubrica_and_flags(rub->rub, rub->new, rub->empty, 
						rub->modified, current_page); 
      rubrica_addressbook_set_path_and_name(rub->path, rub->name, current_page);
      rubrica_addressbook_set_label_text(_("no name"), current_page);
*/

//      gtk_object_set_data(GTK_OBJECT(rub->child), "rubrica", rub);

      rubrica_copy_rubrica(rub);
//      rubrica_addressbook_make_this_rubrica_current(rub);
    }

  rubrica_addressbook_set_closing_page(FALSE);
}


void rubrica_addressbook_show_column_set(gchar *key, gboolean bool)
{
  GtkWidget *list;
  gint pages = 0;
  gint i;

  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_CARD) == 0)
    addressbook->show_card = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME) == 0)
    addressbook->show_first_name = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_LAST_NAME) == 0)
    addressbook->show_last_name = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_PROFESSION) == 0)
    addressbook->show_profession = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_CITY) == 0)
    addressbook->show_city = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_COUNTRY) == 0)
    addressbook->show_country = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_WEB) == 0)
    addressbook->show_web = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_EMAIL) == 0)
    addressbook->show_email = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_TELEPHONE) == 0)
    addressbook->show_telephone = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_COMPANY) == 0)
    addressbook->show_comapany = bool;
  if (strcmp(key, RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT) == 0)
    addressbook->show_assigment = bool;

  pages = rubrica_addressbook_get_pages();

  for (i = 0; i < pages; i++)
    {
      list = rubrica_addressbook_get_clist(i);

      gtk_clist_set_column_visibility(GTK_CLIST (list), 1, addressbook->show_card);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 2, addressbook->show_first_name);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 3, addressbook->show_last_name);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 4, addressbook->show_profession);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 5, addressbook->show_city);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 6, addressbook->show_country);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 7, addressbook->show_web);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 8, addressbook->show_email);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 9, addressbook->show_telephone);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 10, addressbook->show_comapany);
      gtk_clist_set_column_visibility(GTK_CLIST (list), 11, addressbook->show_assigment);

    }
}

void rubrica_addressbook_show_personal_data_set(gboolean bool)
{
  addressbook->show_all_personal = bool;
}
void rubrica_addressbook_show_job_data_set(gboolean bool)
{
  addressbook->show_all_job = bool;
}

void rubrica_addressbook_show_note_data_set(gboolean bool)
{
  addressbook->show_all_note = bool;
}









