/*
*  program name: Rubrica <http://digilander.iol.it/nfragale/download.html>
*  file: autosave.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <stdio.h>
#include <stdlib.h>
#include <time.h>

#include <gnome.h>
#include <libxml/tree.h>
#include <libxml/parser.h>

#include "autosave.h"
#include "rubrica_log.h"
#include "prefer.h"
#include "file.h"
#include "addressbook.h"
#include "rubrica.h"

static gboolean have_timeout = FALSE;
static gint timeout_tag = 0;
static guint32 wait_time = 0;


void rubrica_autosave_start(guint32 time)
{
  if (time == 0)
    {
      wait_time = rubrica_preferences_get_time_rate();
      
      if (wait_time <= 0)
	wait_time = 15;  /* default time to wait is 15 minites */
    }
  else
    wait_time = time;

  /*     wait_time store the minutes rubrica must wait
	 wait_time *= 60000 (1 minute = 60 seconds * 1000 microseconds)
  */
  wait_time *= 60000;
  timeout_tag = gtk_timeout_add(wait_time, (GtkFunction) rubrica_autosave_save_file, NULL);
  
  have_timeout = TRUE;      
  rubrica_log_write_log("\nAutosave started.");
}


void rubrica_autosave_enable(guint32 time)
{
  rubrica_autosave_start(time);  
}


void rubrica_autosave_disable(void)
{
  if (timeout_tag != 0)
    gtk_timeout_remove(timeout_tag);
  else
    return;

  timeout_tag = 0;
  have_timeout = FALSE;
}


void rubrica_autosave_restart(guint32 time)
{
  rubrica_autosave_disable();
  rubrica_autosave_enable(time);
}


gint rubrica_autosave_save_file(void)
{
  Rubrica *rub;
  gint pages, i;

  pages = rubrica_addressbook_get_pages();

  for (i = 0; i < pages; i++)
    {
      rub = rubrica_addressbook_get_rubrica(i);
  
      rubrica_autosave_write_file(rub, i);      
    }

  g_print("\nRubrica: autosave performed");
  return TRUE;
}


void rubrica_autosave_write_file(Rubrica *rub, gint page)
{
  GList *l;
  xmlDocPtr doc;             /* puntatore al documento xml */
  gchar *filename = NULL;
  gint n; 
  
  n = rand();
  
  if (!rub->tmpfile)
    {
      rubrica_addressbook_set_tmpfile_name(n, page);
    }
 
  filename = rub->tmpfile;

  if (g_file_exists(rub->tmpfile))
    remove(rub->tmpfile);
  
  /* creazione di un nuovo documento xml 
   */
  doc = xmlNewDoc("1.0");
  
  /* creo un nuovo nodo radice rubrica 
   */
  doc->children = xmlNewDocNode(doc, NULL, "Rubrica", NULL);
  xmlSetProp(doc->children, "version", VERSION);

  /* attraverso la rubrica e scrivo i dati 
     nell'albero xml
  */
  for (l = rub->rub; l != NULL; l = l->next) 
    {
      RubricaItem *item = l->data;
      
      rubrica_file_build_xmlnode(doc->children, item);
    }  
  
  if (xmlSaveFormatFile(rub->tmpfile, doc, 1) != -1 )
    {
      gchar *str;

      str = g_strdup_printf("\nRubrica: save %s temporary file", rub->tmpfile);
      g_print("str");
      rubrica_log_write_log(str);

      g_free(str);
    }
  else
    {
      rubrica_log_write_log("\nCan't save temporary file, xmlSaveFormatFile return -1");
      g_print("\nRubrica: Can't save temporary file, xmlSaveFormatFile return -1");
      g_print("\nfile: %s", rub->tmpfile);
    }
  
  xmlFreeDoc(doc);
}


void rubrica_autosave_remove_tmp_files(void)
{
  Rubrica *rub;
  gint pages, i;

  pages = rubrica_addressbook_get_pages();
  
  for (i = 0; i < pages; i++)
    {
      rub = rubrica_addressbook_get_rubrica(i);
  
      if (rub->tmpfile)
	remove(rub->tmpfile);      
    }
}
