/*
*  Rubrica
*  file: interface.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "addressbook.h"
// #include "modulo.h"
#include "rubrica.h"
#include "prefer.h"
#include "prefer-notify.h"
#include "dialoghi.h"

GtkWidget *app;                 /* main window */
GtkWidget *popup;               /* menu popup  */

GtkWidget *clist_dati;
GtkWidget *progressbar;


static GnomeUIInfo file1_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_NEW_ITEM (N_("_New File"), NULL, on_new_file1_activate, NULL),
  GNOMEUIINFO_MENU_OPEN_ITEM (on_open1_activate, NULL),
  GNOMEUIINFO_MENU_SAVE_ITEM (on_save1_activate, NULL),
  GNOMEUIINFO_MENU_SAVE_AS_ITEM (on_save_as1_activate, NULL),
  GNOMEUIINFO_MENU_CLOSE_ITEM (on_close1_activate, NULL),
  GNOMEUIINFO_SEPARATOR,
  {
   /* import */    
    GNOME_APP_UI_ITEM, N_("_Import"),
    NULL,
    on_import_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_i, GDK_MOD1_MASK, NULL
  },
  {
   /* export */    
    GNOME_APP_UI_ITEM, N_("_Export"),
    NULL,
    on_export_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_e, GDK_MOD1_MASK, NULL
  },
  GNOMEUIINFO_SEPARATOR,
  {
   /* preview */    
    GNOME_APP_UI_ITEM, N_("_Preview"),
    NULL,
    on_preview_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_p, GDK_MOD1_MASK, NULL
  },  
  GNOMEUIINFO_SEPARATOR,
  GNOMEUIINFO_MENU_EXIT_ITEM (on_exit1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo edit1_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_UNDO_ITEM (on_undo_activate, NULL),
  GNOMEUIINFO_MENU_REDO_ITEM (on_redo_activate, NULL),
  GNOMEUIINFO_SEPARATOR,
  GNOMEUIINFO_MENU_CUT_ITEM (on_cut1_activate, NULL),
  GNOMEUIINFO_MENU_COPY_ITEM (on_copy1_activate, NULL),
  GNOMEUIINFO_MENU_PASTE_ITEM (on_paste1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo crescente1_uiinfo[] =
{
  {
    GNOME_APP_UI_ITEM, N_("_Increasing"),
    NULL,
    on_crescente1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_c, GDK_MOD1_MASK, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("D_ecreasing"),
    NULL,
    on_decrescente1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    GDK_e, GDK_MOD1_MASK, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo date_menu_uiinfo[] =
{
  {
    GNOME_APP_UI_ITEM, N_("_Creation date"),
    N_("Order cards by creation date"),
    (gpointer) on_creation_date_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, (GdkModifierType) 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("_Modification date"),
    N_("Order cards by last modification date"),
    (gpointer) on_modification_date_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, (GdkModifierType) 0, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo view1_menu_uiinfo[] =
{
  {
    GNOME_APP_UI_ITEM, N_("_Alphabetic"),
    N_("Show the cards in alphabetic order"),
    on_alfabetica1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
/*
  {
    GNOME_APP_UI_ITEM, N_("_Dimensione"),
    N_("Mostra le schede in base alla loro dimensione"),
    on_dimensione1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
*/
  {
    GNOME_APP_UI_SUBTREE, N_("Da_te"),
    N_("Show cards by date order"),
    date_menu_uiinfo, NULL, NULL,
    GNOME_APP_PIXMAP_NONE, NULL,
    0, 0, NULL
  },
  GNOMEUIINFO_SEPARATOR,
  {
    GNOME_APP_UI_RADIOITEMS, NULL, NULL, crescente1_uiinfo,
    NULL, NULL, 0, NULL, 0, 0, NULL 
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo settings1_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_PREFERENCES_ITEM (on_preferences1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo help1_menu_uiinfo[] =
{
  GNOMEUIINFO_MENU_ABOUT_ITEM (on_about1_activate, NULL),
  {
    GNOME_APP_UI_ITEM, N_("_Calabria"),
    N_("Visit Calabria"),
    on_calabria1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_FILENAME, "rubrica/small_calabria.xpm",
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("_Dedicated to..."),
    N_("This program is dedicated to..."),
    on_dedicato_a1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
    0, 0, NULL
  },
   GNOMEUIINFO_SEPARATOR,
  {
    GNOME_APP_UI_ITEM, N_("_Help me"),
    N_("Help me in rubrica localization"),
    on_localization_activate, NULL, NULL,
    GNOME_APP_PIXMAP_FILENAME, "rubrica/small_bug.xpm",
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("I found a _bug"),
    N_("Email me a bug description"),
    on_bug_activate, NULL, NULL,
    GNOME_APP_PIXMAP_FILENAME, "rubrica/small_bug.xpm",
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("De_veloping"),
    N_("Rubrica will have..."),
    on_developing1_activate, NULL, NULL,
    GNOME_APP_PIXMAP_FILENAME, "rubrica/small_devel.xpm",
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("_Don't crashes but..."),
    N_("Rubrica don't crashes but some feature could not work"),
    on_unfinished_activate, NULL, NULL,
    GNOME_APP_PIXMAP_FILENAME, "rubrica/small_news.xpm",
    0, 0, NULL
  },
  GNOMEUIINFO_SEPARATOR,
  {
    GNOME_APP_UI_ITEM, N_("Rubrica _Home page"),
    N_("Go to Rubrica Home Page"),
    on_home_page_activate, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_HOME,
    0, 0, NULL
  },
  {
    GNOME_APP_UI_ITEM, N_("e_Mail me"),
    N_("Do you want ask anything?"),
    on_email_me_activate, NULL, NULL,
    GNOME_APP_PIXMAP_FILENAME, "rubrica/small_emailme.xpm",
    0, 0, NULL
  },
  GNOMEUIINFO_END
};

static GnomeUIInfo menubar1_uiinfo[] =
{
  GNOMEUIINFO_MENU_FILE_TREE (file1_menu_uiinfo),
  GNOMEUIINFO_MENU_EDIT_TREE (edit1_menu_uiinfo),
  GNOMEUIINFO_MENU_VIEW_TREE (view1_menu_uiinfo),
  GNOMEUIINFO_MENU_SETTINGS_TREE (settings1_menu_uiinfo),
  GNOMEUIINFO_MENU_HELP_TREE (help1_menu_uiinfo),
  GNOMEUIINFO_END
};


static GnomeUIInfo popmenu[] =
{
  GNOMEUIINFO_MENU_CUT_ITEM (on_pop_cut_activate, NULL),
  GNOMEUIINFO_MENU_COPY_ITEM (on_pop_copy_activate, NULL),
  GNOMEUIINFO_MENU_PASTE_ITEM (on_pop_paste_activate, NULL),
  GNOMEUIINFO_SEPARATOR,
  {
    GNOME_APP_UI_ITEM, N_("_Modify"),
    NULL,
    on_pop_modifica_activate, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CONVERT,
    0, 0, NULL
  },
  GNOMEUIINFO_END
};


GtkWidget*
create_app (GConfClient *client)
{
  RubricaAddressBook *addbook;

  GtkWidget *dock1;
  GtkWidget *toolbar1;
  GtkWidget *tmp_toolbar_icon;

  GtkWidget *bNuovo;
  GtkWidget *bApri;
  GtkWidget *bSalva;
  GtkWidget *bClose;
  GtkWidget *bAggiungi;
  GtkWidget *bElimina;
  GtkWidget *bModifica;
  GtkWidget *bPrima;
  GtkWidget *bUltima;
  GtkWidget *bCerca;
  GtkWidget *bEsci;
  GtkWidget *bPrecedente;
  GtkWidget *bSuccessivo;

  GtkWidget *table1;

  GtkWidget *frame_window;
  GtkWidget *frame_cards;
  GtkWidget *frame_data;

  GtkWidget *data_scrollwin;
  GtkWidget *hbuttonbox1;

  GtkWidget *label5; 
  GtkWidget *label7; 
  GtkWidget *label8;
  GtkWidget *label10;
  GtkWidget *label_path;

  GtkWidget *hpaned1;
  GtkWidget *appbar1;
  
  GtkWidget *vbox1;
  GtkWidget *vbox2;
  GtkWidget *hbox1;
  GtkWidget *hbox2;

  GtkTooltips *tooltips;

  g_print("\nRubrica: begin interface creation\n");
  
  addbook = rubrica_get_addressbook();

  tooltips = gtk_tooltips_new ();

  app = gnome_app_new ("Rubrica", "Rubrica");
  gtk_widget_set_name (app, "app");
  gtk_window_set_default_size(GTK_WINDOW(app), 800,500);
  gtk_object_set_data (GTK_OBJECT (app), "app", app);
  gtk_container_set_border_width (GTK_CONTAINER (app), 4);
  gtk_window_set_position (GTK_WINDOW (app), GTK_WIN_POS_CENTER);
  gtk_window_set_policy (GTK_WINDOW (app), TRUE, TRUE, TRUE);

  dock1 = GNOME_APP (app)->dock;
  gtk_widget_set_name (dock1, "dock1");
  gtk_widget_ref (dock1);
  gtk_object_set_data_full (GTK_OBJECT (app), "dock1", dock1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dock1);

  /*      creazione della barra dei menu 
   */
  gnome_app_create_menus (GNOME_APP (app), menubar1_uiinfo);

  /*      creazione della toolbar 
  */
  toolbar1 = gtk_toolbar_new (GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_BOTH);
  gtk_object_set_data(GTK_OBJECT (app), "toolbar1", toolbar1);
  gtk_widget_show (toolbar1);

  gnome_app_add_toolbar (GNOME_APP (app), GTK_TOOLBAR (toolbar1), "toolbar1",
                                GNOME_DOCK_ITEM_BEH_EXCLUSIVE,
                                GNOME_DOCK_TOP, 1, 0, 0);

  gtk_container_set_border_width (GTK_CONTAINER (toolbar1), 1);
  gtk_toolbar_set_space_size (GTK_TOOLBAR (toolbar1), 20);
  gtk_toolbar_set_space_style (GTK_TOOLBAR (toolbar1), GTK_TOOLBAR_SPACE_LINE);
  gtk_toolbar_set_button_relief (GTK_TOOLBAR (toolbar1), GTK_RELIEF_NONE);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_NEW);

  bNuovo = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("New"),
                                _("Make a new address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bNuovo", bNuovo);
  gtk_widget_show (bNuovo);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_OPEN);
  bApri = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Open"),
                                _("Open an existing address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bApri", bApri);
  gtk_widget_show (bApri);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_SAVE);
  bSalva = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Save"),
                                _("Save current address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bSalva", bSalva);
  gtk_widget_show (bSalva);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_CLOSE);
  bClose = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Close"),
                                _("Close current file"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bClose", bClose);
  gtk_widget_show (bClose);

  gtk_toolbar_append_space (GTK_TOOLBAR (toolbar1));

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_ADD);
  bAggiungi = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Add"),
                                _("Add a card to the address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bAggiungi", bAggiungi);
  gtk_widget_show (bAggiungi);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_REMOVE);
  bElimina = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Delete"),
                                _("Delete a card from address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bElimina", bElimina);
  gtk_widget_show (bElimina);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_CONVERT);
  bModifica = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Modify"),
                                _("Modify the selected card"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bModifica", bModifica);
  gtk_widget_show (bModifica);

  gtk_toolbar_append_space (GTK_TOOLBAR (toolbar1));

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_TOP);
  bPrima = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("First"),
                                _("Show first card in the address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bPrima", bPrima);
  gtk_widget_show (bPrima);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_BOTTOM);
  bUltima = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Last"),
                                _("Show last card in the address book"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bUltima", bUltima);
  gtk_widget_show (bUltima);

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_SEARCH);
  bCerca = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Search"),
                                _("Search card ..."), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bCerca", bCerca);
  gtk_widget_show (bCerca);

  gtk_toolbar_append_space (GTK_TOOLBAR (toolbar1));

  tmp_toolbar_icon = gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_EXIT);
  bEsci = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar1),
                                GTK_TOOLBAR_CHILD_BUTTON,
                                NULL,
                                _("Exit"),
                                _("Exit program"), NULL,
                                tmp_toolbar_icon, NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (app), "bEsci", bEsci);
  gtk_widget_show (bEsci);

  

  /* ******************************************************************* */

  /* ***********************************************
     inizia la costruzione della tabella contenente
     le clist e i dati statistici

     Make table that contains clists and data (inserted address and path)
     ***********************************************
  */	

  /* rendo insensibili gli elementi di menu non ancora realizzati */
  gtk_widget_set_sensitive(edit1_menu_uiinfo[0].widget, FALSE);   /* undo   */
  gtk_widget_set_sensitive(edit1_menu_uiinfo[1].widget, FALSE);   /* redo   */
    
  /*     creo il menu popup 
	 make popup menu 
  */
  popup = gnome_popup_menu_new(popmenu);

  /* App Box */
  vbox1 = gtk_vbox_new (FALSE, 3);
  gtk_widget_show (vbox1);
  gnome_app_set_contents (GNOME_APP (app), vbox1);

  /* Frame for appbox */
  frame_window = gtk_frame_new (_(" Rubrica "));
  gtk_widget_show (frame_window);
  gtk_box_pack_start (GTK_BOX (vbox1), frame_window, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_window), 8);

  /* vertical paned 
     separatore verticale
   */
  hpaned1 = gtk_hpaned_new ();
  gtk_widget_show (hpaned1);
  gtk_container_add (GTK_CONTAINER (frame_window), hpaned1);
  gtk_container_set_border_width (GTK_CONTAINER (hpaned1), 10);
  gtk_paned_set_position (GTK_PANED (hpaned1), 380);

  /* Now working window is didived in two boxes, in left box there is 
     cards notebook, in the right one there is the data box
  */

  /*      LEFT SIDE OF WORKING WINDOW
   */
  /*    cards frame
  */
  frame_cards = gtk_frame_new (_(" Cards "));
  gtk_widget_show (frame_cards);
  gtk_paned_pack1 (GTK_PANED (hpaned1), frame_cards, FALSE, TRUE);
  gtk_container_set_border_width (GTK_CONTAINER (frame_cards), 2);   

  /*    
	Configuro il notebook contenuto nel widget RubricaAddressBook
	cards notebook
  */
  gtk_object_set_data(GTK_OBJECT (app), "cards_notebook", addbook->notebook);
  gtk_container_add (GTK_CONTAINER (frame_cards), addbook->notebook);
  gtk_container_set_border_width (GTK_CONTAINER (addbook->notebook), 2);
  gtk_notebook_set_scrollable(GTK_NOTEBOOK(addbook->notebook), TRUE);

  /*    TAB POSITION, WILL BE CONFIGURABLE BY USER.
   */
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (addbook->notebook), GTK_POS_BOTTOM);
  gtk_widget_show (addbook->notebook);


  /*    RIGHT SIDE OF WORKING WINDOW
	Data frame
  */
  frame_data = gtk_frame_new (_(" Data "));
  gtk_widget_show (frame_data);
  gtk_paned_pack2 (GTK_PANED (hpaned1), frame_data, TRUE, TRUE);
  gtk_container_set_border_width (GTK_CONTAINER (frame_data), 2);

  /*     Data scrolle window
  */
  data_scrollwin = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (data_scrollwin);
  gtk_container_add (GTK_CONTAINER (frame_data), data_scrollwin);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (data_scrollwin), 
				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  /*    DATA CLIST
   */
  clist_dati = gtk_clist_new (3);
  gtk_object_set_data (GTK_OBJECT (app), "data_clist", clist_dati);
  gtk_container_add (GTK_CONTAINER (data_scrollwin), clist_dati);
  gtk_clist_set_column_width (GTK_CLIST (clist_dati), 0, 15);
  gtk_clist_set_column_width (GTK_CLIST (clist_dati), 1, 160);
  gtk_clist_set_column_width (GTK_CLIST (clist_dati), 2, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_dati));
  gtk_clist_set_column_auto_resize(GTK_CLIST(clist_dati), 2, TRUE);
  gtk_widget_show (clist_dati);

  /*    Data clist label
  */
  label5 = gtk_label_new ("");
  gtk_widget_show (label5);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dati), 0, label5);

  label7 = gtk_label_new ("");
  gtk_widget_show (label7);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dati), 1, label7);

  label8 = gtk_label_new ("");
  gtk_widget_show (label8);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dati), 2, label8);

  /*    BOX UNDER CLISTS
  */
  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
  
  /*    Buttons table
  */
  table1 = gtk_table_new (2, 1, FALSE);
  gtk_widget_show (table1);
  gtk_box_pack_start (GTK_BOX (hbox1), table1, TRUE, TRUE, 0);

  /*    Horizontal button box. Contain Prev and Next button
   */
  hbuttonbox1 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox1);
  gtk_table_attach (GTK_TABLE (table1), hbuttonbox1, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_SPREAD);

  /*    PREV BUTTON
   */
  bPrecedente = gnome_stock_button (GNOME_STOCK_BUTTON_PREV);
  gtk_object_set_data (GTK_OBJECT (app), "prev_button", bPrecedente);
  gtk_widget_show (bPrecedente);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), bPrecedente);
  GTK_WIDGET_SET_FLAGS (bPrecedente, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, bPrecedente, _("Show previous card"),NULL);

  /*    NEXT BUTTON
   */
  bSuccessivo = gnome_stock_button (GNOME_STOCK_BUTTON_NEXT);
  gtk_object_set_data (GTK_OBJECT (app), "next_button", bSuccessivo);
  gtk_widget_show (bSuccessivo);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), bSuccessivo);
  GTK_WIDGET_SET_FLAGS (bSuccessivo, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, bSuccessivo, _("Show next card"), NULL);

  /*    right boxes. This contain:
	- path
	- scrollbar 
  */
  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox2);
  gtk_box_pack_start (GTK_BOX (hbox1), vbox2, TRUE, TRUE, 0);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, TRUE, 0);

  /*    Progress bar
	display the number of item contained into addressbook
  */
  progressbar = gtk_progress_bar_new ();
  gtk_object_set_data (GTK_OBJECT (app), "item_progressbar", progressbar);
  gtk_widget_show (progressbar);
  gtk_box_pack_start (GTK_BOX (hbox2), progressbar, FALSE, FALSE, 0);
  gtk_widget_set_usize (progressbar, 80, 0);
  gtk_progress_configure (GTK_PROGRESS (progressbar), 0, 0, 1000);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar), "Item(s) %V%");

  /*    label "path"
  */
  label10 = gtk_label_new (_("Path: "));
  gtk_widget_show (label10);
  gtk_box_pack_start (GTK_BOX (hbox2), label10, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label10), 3, 0);
  
  /*    label that will display file's path
	Set to "" or to user home at start
  */
  label_path = gtk_label_new ("");
  gtk_object_set_data (GTK_OBJECT (app), "label_path", label_path);
  gtk_widget_show (label_path);
  gtk_box_pack_start (GTK_BOX (hbox2), label_path, FALSE, FALSE, 0);

  /*    Gnome appbar
   */
  appbar1 = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_NEVER);
  gtk_object_set_data (GTK_OBJECT (app), "appbar", appbar1);
  gtk_widget_show (appbar1);
  gnome_app_set_statusbar (GNOME_APP (app), appbar1);

  gnome_app_install_menu_hints (GNOME_APP (app), menubar1_uiinfo);

  /*    CALLBACKS 
   */
  
  gtk_signal_connect(GTK_OBJECT(app), "delete_event", 
		     GTK_SIGNAL_FUNC(exit_rubrica), NULL);

  /*    TOOLBAR CALLBACKS
   */
  gtk_signal_connect (GTK_OBJECT (bNuovo), "clicked",
                      GTK_SIGNAL_FUNC (on_bNuovo_clicked),
                      (gpointer) app);
  gtk_signal_connect (GTK_OBJECT (bApri), "clicked",
                      GTK_SIGNAL_FUNC (on_bApri_clicked),
                      app);
  gtk_signal_connect (GTK_OBJECT (bSalva), "clicked",
                      GTK_SIGNAL_FUNC (on_bSalva_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (bClose), "clicked",
                      GTK_SIGNAL_FUNC (on_bClose_clicked),
                      addbook->notebook);
  gtk_signal_connect (GTK_OBJECT (bAggiungi), "clicked",
                      GTK_SIGNAL_FUNC (on_bAggiungi_clicked),
                      addbook->notebook);
  gtk_signal_connect (GTK_OBJECT (bElimina), "clicked",
                      GTK_SIGNAL_FUNC (on_bElimina_clicked),
                      addbook->notebook);
  gtk_signal_connect (GTK_OBJECT (bModifica), "clicked",
                      GTK_SIGNAL_FUNC (on_bModifica_clicked),
                      addbook->notebook);

  gtk_signal_connect (GTK_OBJECT (bPrima), "clicked",
                      GTK_SIGNAL_FUNC (on_bPrima_clicked),
                      addbook->notebook);
  gtk_signal_connect (GTK_OBJECT (bUltima), "clicked",
                      GTK_SIGNAL_FUNC (on_bUltima_clicked),
                      addbook->notebook);

  gtk_signal_connect (GTK_OBJECT (bCerca), "clicked",
                      GTK_SIGNAL_FUNC (on_bCerca_clicked),
                      NULL);

  gtk_signal_connect (GTK_OBJECT (bEsci), "clicked",
                      GTK_SIGNAL_FUNC (on_exit_clicked),
                      NULL);

  /*    CALLBACK PER I BOTTONI DELLA FINESTRA
  */  
  gtk_signal_connect (GTK_OBJECT (bPrecedente), "clicked",
                      GTK_SIGNAL_FUNC (on_bPrecedente_clicked),
                      addbook->notebook);
  gtk_signal_connect (GTK_OBJECT (bSuccessivo), "clicked",
                      GTK_SIGNAL_FUNC (on_bSuccessivo_clicked),
                      addbook->notebook);

  /*    CALLBACK PER LE CLIST --  DATI
  */
  gtk_signal_connect (GTK_OBJECT (clist_dati), "select-row",
		      GTK_SIGNAL_FUNC (on_dati_clist_select_row),
                      NULL);
  gtk_signal_connect(GTK_OBJECT(clist_dati), "button_press_event",
		     GTK_SIGNAL_FUNC(on_dati_clist_button_click),
		     NULL);


  /*    CALLBACK PER LE PAGINE DI NOTEBOOK
   */
  gtk_signal_connect(GTK_OBJECT(addbook->notebook), "switch-page",
		     GTK_SIGNAL_FUNC(on_switch_pages_cb),
		     NULL);


  gtk_object_set_data (GTK_OBJECT (app), "tooltips", tooltips);

  /*inizializzo la struttura vista */  
  rubrica_view_init(clist_dati, progressbar);

  /* configuro il widget label_path, in modo che ad ogni variazione
     di addressbook, se nelle preferenze  settatata l'opzione show path,
     la path venga mostrata
  */
  rubrica_config_path_notify(label_path, client, RUBRICA_KEY_SHOW); 

  g_print("Rubrica: Interface done...\n");

  return app;
}




